@@ -1,22 +1,9 @@
-/**
- This file is part of Kig, a KDE program for Interactive Geometry...
- Copyright (C) 2002  Dominique Devriese <devriese@kde.org>
+/*
+    This file is part of Kig, a KDE program for Interactive Geometry...
+    SPDX-FileCopyrightText: 2002 Dominique Devriese <devriese@kde.org>
 
- This program is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2 of the License, or
- (at your option) any later version.
-
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301
- USA
-**/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kig.h"
 
@@ -38,7 +25,7 @@
 
 static int convertToNative( const QUrl &file, const QByteArray& outfile )
 {
-  KPluginLoader libraryLoader( QStringLiteral("kigpart") );
+  KPluginLoader libraryLoader( QStringLiteral("kf5/parts/kigpart") );
   QLibrary library( libraryLoader.fileName() );
   int ( *converterfunction )( const QUrl&, const QByteArray& );
   converterfunction = ( int ( * )( const QUrl&, const QByteArray& ) ) library.resolve( "convertToNative" );
@@ -67,7 +54,7 @@ static void dataMigration()
   if ( !file.isEmpty() )
   {
     QFile macros( file );
-    const QDir writeableDataLocation ( QStandardPaths::writableLocation( QStandardPaths::DataLocation ) );
+    const QDir writeableDataLocation ( QStandardPaths::writableLocation( QStandardPaths::AppLocalDataLocation ) );
     const QDir typesDir( writeableDataLocation.absoluteFilePath( QStringLiteral("kig-types") ) );
 
     if ( !typesDir.exists() )
